@@ -61,10 +61,10 @@
 namespace
 {
 bool        resetDaemonQueued = false;
-TQCString    korganizerName = "korganizer";
-TQString     korgStartError;
+TQCString   korganizerName = "korganizer";
+TQString    korgStartError;
 #define     KORG_DCOP_OBJECT    "KOrganizerIface"
-const char* KORG_DCOP_WINDOW  = "KOrganizer MainWindow";
+//const char* KORG_DCOP_WINDOW  = "KOrganizer MainWindow";  // not used
 const char* KMAIL_DCOP_WINDOW = "kmail-mainwindow#1";
 
 bool sendToKOrganizer(const KAEvent&);
